import babel from "babel-core";
const opt = {
	auxiliaryCommentAfter: null,
	auxiliaryCommentBefore: null,
	babelrc: false,
	comments: true,
	compact: "auto",
	env: {},
	parserOpts: {},
	plugins: [],
	presets: [],
	retainLines: false,
	sourceType: "module",
};

let regexp = /^(.*)\((\d+)\:(\d+)\)\s*$/;

export let task = {
	async transform (code, {
		auxiliaryCommentAfter = opt.auxiliaryCommentAfter,
		auxiliaryCommentBefore = opt.auxiliaryCommentBefore,
		babelrc = opt.babelrc,
		comments = opt.comments,
		compact = opt.compact,
		env = opt.env,
		parserOpts = opt.parserOpts,
		plugins = opt.plugins,
		presets = opt.presets,
		retainLines = opt.retainLines,
		sourceType = opt.sourceType,
	}) {
		let options = {
			auxiliaryCommentAfter, auxiliaryCommentBefore, comments, compact,
			babelrc, env, parserOpts, plugins, presets, sourceType,
		}
		try{
			let result = babel.transform(code, options);
			return result.code;
		} catch (e) {
			let ln,cl,tx = e.message;
			let info = regexp.exec(tx);
			if (info) {
				tx = info[1];
				ln = info[2];
				cl = info[3];
			}
			this.echo({
				lv:"error",
				at:"babel",
				fn:this.absPath,
				ln, cl, tx,
			});
		}
	}
}
